<?php
// $Id: template.php,v 1.7.2.1 2011/01/03 14:23:23 mauro72 Exp $

require_once('theme-settings.php');

/**
 * Initialize theme settings.
 */
global $theme_key;
opengrid_initialize_theme_settings($theme_key);

// Auto-rebuild the theme registry during theme development.
if (theme_get_setting('opengrid_rebuild_registry')) {
  drupal_rebuild_theme_registry();
}

if(theme_get_setting('css_switch') == 0 && theme_get_setting('container_columns') != 'container_24'){
  drupal_add_css(drupal_get_path('theme', 'opengrid') .'/css/960_16.css', 'theme', 'screen');
}
if(theme_get_setting('css_switch') == 0 && theme_get_setting('container_columns') == 'container_24'){
  drupal_add_css(drupal_get_path('theme', 'opengrid') .'/css/960_24.css', 'theme', 'screen');
}
if(theme_get_setting('css_switch') == 1 && theme_get_setting('container_columns') == 'container_24'){
  drupal_add_css(drupal_get_path('theme', 'opengrid') .'/css/960_24_fluid.css', 'theme', 'screen');
}

if(theme_get_setting('scroll_to_top') == 1){
  drupal_add_js(drupal_get_path('theme', 'opengrid') .'/js/scrolToTop.js');
}

if(theme_get_setting('hide_sidebars') == 1){
  drupal_add_js(drupal_get_path('theme', 'opengrid') .'/js/layout.js');  
}


/**
 * Implements HOOK_theme().
 */
function opengrid_theme(&$existing, $type, $theme, $path) {
  if (!db_is_active()) {
    return array();
  }
  $items = array();
  $items['containers_settings_table'] = array(
    'arguments' => array('form')
  );
  $items['grids_settings_table'] = array(
    'arguments' => array('form')
  );

  return $items;
}

function opengrid_preprocess(&$vars, $hook) {
  //Code to detect regions activated by context module
  $regions = array();
    if (module_exists('context')) {
      foreach(context_active_contexts() as $context){
        if(is_array($context->reactions['block']['blocks'])){
          foreach($context->reactions['block']['blocks'] as $block){
              $regions[$block['region']] = $block['region'];
          }
        }
      }
    } 
  
  $vars['my_layout'] = 'no_sidebars';
  
  if (block_list('sidebar_first') || in_array('sidebar_first',$regions)){
    $vars['my_layout'] = 'sidebar_first';
  }
  
  if (block_list('sidebar_second') || in_array('sidebar_second', $regions)){
    $vars['my_layout'] = ($vars['my_layout'] == 'sidebar_first') ? 'both_sidebars' : 'sidebar_second';
  }
  
  if(drupal_is_front_page()){
    $theme = variable_get('theme_default','none');
    $settings = theme_get_settings($theme);
    $vars['my_layout'] = ($settings['frontpage_layout_checkbox'] == 1) ? 'frontpage' : $vars['my_layout']; 
  }
}

function opengrid_preprocess_page(&$vars) {
  $theme = variable_get('theme_default','none');
  
  // We need to re-do the $layout and body classes because
  // template_preprocess_page() assumes sidebars are named 'left' and 'right'.
  $vars['layout'] = 'none';
  if (!empty($vars['sidebar_first'])) {
    $vars['layout'] = 'first';
  }
  if (!empty($vars['sidebar_second'])) {
    $vars['layout'] = ($vars['layout'] == 'first') ? 'both' : 'second';
  }
  // If the layout is 'none', then template_preprocess_page() will already have
  // set a 'no-sidebars' class since it won't find a 'left' or 'right' sidebar.
  $vars['body_classes'] = explode(' ', $vars['body_classes']);
  if ($vars['layout'] != 'none') {
    // Remove the incorrect 'no-sidebars' class.
    if ($index = array_search('no-sidebars', $vars['body_classes'])) {
      unset($vars['body_classes'][$index]);
    }
    // Set the proper layout body classes.
    if ($vars['layout'] == 'both') {
      $vars['body_classes'][] = 'two-sidebars';
    }
    else {
      $vars['body_classes'][] = 'one-sidebar';
      $vars['body_classes'][] = 'sidebar-' . $vars['layout'];
    }
  }
  $vars['body_classes'] = implode(' ', $vars['body_classes']);  
  
  // adds classes to primary links configured in theme settings
  if (theme_get_setting('navigation_extras') != '') {
    $vars['main_navigation_classes'] .= ' '. theme_get_setting('navigation_extras');
  }
  if (theme_get_setting('navigation_classes') != 'none') {
    $vars['main_navigation_classes'] .= ' '. theme_get_setting('navigation_classes');
  } 

  $vars['primary_links'] = theme('links',$vars['primary_links']);
  $vars['secondary_links'] = theme('links',$vars['secondary_links']);
  
  //rewrite primary links for dropdown support  
  if(theme_get_setting('primary_dropdown') == 1){
    $vars['primary_links'] = menu_tree(variable_get('menu_primary_links_source', 'primary-links'));
  }
  
  //loads grid values from the theme_settings variable 
  if (is_file(drupal_get_path('theme', 'opengrid') . '/opengrid_grid_assembler.inc') && !is_file(drupal_get_path('theme', $theme) . '/opengrid_layout.inc')) {
    include('opengrid_grid_assembler.inc');
    $vars = opengrid_grid_settings_vars($vars);
  }
  
  //load grid values for the grid from code, if the file exists
  if (is_file(drupal_get_path('theme', $theme) . '/opengrid_layout.inc')) {
    $layout = $vars['my_layout'] .'_layout'; 
    include(drupal_get_path('theme', $theme) . '/opengrid_layout.inc');
  }  
  
  // Add liquid-layout class to the body
  if (theme_get_setting('css_switch') == 1) {
    $vars['body_classes'] .= ' liquid-layout';
  }
  if (theme_get_setting('scroll_to_top') == 1) {
    $vars['scroll_to_top'] = t('Back to Top');
  }
  //body classes adjustments
  $vars['body_classes'] = str_replace('not-front','',$vars['body_classes']);
  if(arg(0) == 'node' && arg(1) == 'add'){
    $vars['body_classes'] .= ' node-add-section';   
  }
  if(arg(0) == 'node' && arg(2) == 'edit'){
    $vars['body_classes'] .= ' node-edit-section';   
  }  
  
  if (module_exists('page_title')) {
    $vars['head_title'] = page_title_page_get_title();
  } 
  
  //modifing local task in a similar way they are in Garland theme
  if ($primary = menu_primary_local_tasks()) {
      $output = "<ul class=\"tabs primary\">\n". $primary ."</ul>\n";
      $vars['tabs'] = $output;
  }  
  if ($secondary = menu_secondary_local_tasks()) {
      //$output = "<ul class=\"tabs secondary\">\n". $secondary ."</ul>\n";
      $vars['tabs2'] = $secondary;
  }
  if($vars['tabs']){
    $vars['title_class'] = 'with-tabs';  
  }

}

function opengrid_preprocess_node(&$vars) {
  $vars['node_classes'] = $vars['page'] ? 'node' : 'teaser';
}

function opengrid_preprocess_block(&$vars){
  $theme = variable_get('theme_default','none');  
  $block = $vars['block'];
  
  $block_id = 'block-'. $block->module .'-'. $block->delta;

  $vars['block_id'] = $block_id;
  $vars['block_classes'] .= ' block block-'. $block->module;
  
  //Loads the variables thats controls the grid settings for the blocks
  if (!is_file(drupal_get_path('theme', $theme) . '/opengrid_blocks.inc')) {
    $settings = variable_get('theme_'. $theme .'_settings',array());
    
    $block_classes = $settings[$vars['my_layout'].'_layout']['blocks_settings'][$block_id];

    if(is_array($block_classes)){
      foreach($block_classes as $op => $value){
          $classes_array[$op] = ($op != 'extras') ? $op .'_'. $value : $value;   
      }      
      $classes = implode(' ', $classes_array);
      $vars['block_classes'] .= ' '. $classes;
    }
  }  
  //load grid values for the grid from code, if the file exists
  if (is_file(drupal_get_path('theme', $theme) . '/opengrid_blocks.inc')) {
      $layout = $vars['my_layout'] .'_layout'; 
      include(drupal_get_path('theme', $theme) . '/opengrid_blocks.inc');
  }     
}

/**
 * Returns a table to configure container settings.
 */
function opengrid_containers_settings_table(&$form){
  $rows = array();
  $header = array('', t('Columns'),t('Extras'));

  foreach(element_children($form) as $key) {
    $name = $form[$key]['grid']['#title'];
    $form[$key]['grid']['#title'] = '';
    $form[$key]['extras']['#title'] = '';
    $row = array(
      $name,
      drupal_render($form[$key]['grid']),
      drupal_render($form[$key]['extras']),
    );
    $rows[] = $row;
  }

  $output = theme('table', $header, $rows);
  return $output;
}

/**
 *  Returns a table to configure grid settings.
 */
function opengrid_grids_settings_table(&$form){
  $rows = array();
  $header = array (
    t('Region'), 
    t('Width'),
    t('Prefix'),
    t('Suffix'),
    t('Push'),
    t('Pull'),
    t('Alpha'),
    t('Omega'),
    t('Extras'),
  );

  foreach (element_children($form) as $key) {
    $name = $form[$key]['grid']['#title'];

    $form[$key]['grid']['#title'] = '';
    $container = t('No container');
    if ($key != 'main_grid' && $key != 'first_sidebar_grid' && $key != 'second_sidebar_grid') {
      $container = drupal_render($form[$key]['container']);
    }
    $row = array(
      $name,
      drupal_render($form[$key]['grid']),
      drupal_render($form[$key]['prefix']),
      drupal_render($form[$key]['suffix']),
      drupal_render($form[$key]['push']),
      drupal_render($form[$key]['pull']),
      drupal_render($form[$key]['alpha']),
      drupal_render($form[$key]['omega']),
      drupal_render($form[$key]['extras']),
      //$container,
    );
    $rows[] = $row;
  }

  $output = theme('table', $header, $rows);
  return $output;
}

/**
 * File element override
 * Sets form file input max width
 */
function opengrid_file($element) {
  $element['#size'] = ($element['#size'] > 40) ? 40 : $element['#size'];
  return theme_file($element);
}

/*
*  Load extra files for superfish dropdowns 
*/
if(theme_get_setting('primary_dropdown') == 1){
  drupal_add_js(drupal_get_path('theme','opengrid').'/js/superfish/superfish.js');
  drupal_add_js(drupal_get_path('theme','opengrid').'/js/superfish/superfish_config.js');
  drupal_add_css(drupal_get_path('theme','opengrid').'/js/superfish/superfish.css');
  drupal_add_css(drupal_get_path('theme','opengrid').'/js/superfish/superfish-navbar.css');
}

function opengrid_node_form($form) {
  //fixed position forsubmit buttons
  if (theme_get_setting('fixed_buttons') == 1) {
    $form['buttons']['#prefix'] = '<div class="buttons-wrapper">';
    $form['buttons']['#suffix'] = '</div>'; 

  }
  $form['buttons']['#weight'] = 50;
  return drupal_render($form);
}
/*
* hook to theme message
* Return a themed set of status and/or error messages. The messages are grouped by type.
* @display (optional) Set to 'status' or 'error' to display only messages of that type.
* return: A string containing the messages.
*/

function opengrid_status_messages($display = NULL) {
  if(module_exists('jquery_ui')){
    jquery_ui_add('ui.draggable');
  }
  foreach (drupal_get_messages($display) as $type => $messages) {
    $type = ($type == 'status' && theme_get_setting('auto_hide_messages') == 1) ? 'status autohide' : 'status';
      $output .= "<div class=\"messages ui-draggable $type \">\n";
      $output .= '<div class="inner-message">';  
      $output .= "<h2 class=\"messages-label $type\">" . t(drupal_ucfirst($type)) . "</h2>\n";  
      if (count($messages) > 1) {
        $output .= " <ul>\n";
        foreach ($messages as $message) {
          $output .= '  <li>'. $message ."</li>\n";
        }
        $output .= " </ul>\n";
      }
      else {
        $output .= $messages[0];
      }
      $output .= '<span class="close">'. t('Close') .'</span></div>';       
    $output .= "</div>\n";
  }
 
  return $output;
}

